@@ -5,7 +5,7 @@ import time
 
 import contextlib
 
-from .funcs import fetch_reporter, in_main_thread
+from .funcs import fetch_reporter
 
 ##__________________________________________________________________||
 def atpbar(iterable, name=None, time_track=False):
@@ -39,7 +39,7 @@ def atpbar(iterable, name=None, time_track=False):
     return Atpbar(iterable, name=name, len_=len_, time_track=time_track)
 
 ##__________________________________________________________________||
-class Atpbar(object):
+class Atpbar:
     """Progress bar
 
     An iterable that wraps another iterable and shows the progress
@@ -82,8 +82,7 @@ class Atpbar(object):
         try:
             report = dict(
                 taskid=self.id_, name=self.name,
-                done=0, total=self.len_,
-                pid=os.getpid(), in_main_thread=in_main_thread())
+                done=0, total=self.len_)
             if self.time_track:
                 report['start_time'] = start_time=time.time()
             self.reporter.report(report)
@@ -111,12 +110,14 @@ def report_last(pbar):
     try:
         yield
     finally:
-        if not pbar.loop_complete:
-            if pbar.reporter is not None:
-                try:
-                    report = dict(taskid=pbar.id_, first=False, last=True)
-                    pbar.reporter.report(report)
-                except:
-                    pass
+        if pbar.loop_complete:
+            return
+        if pbar.reporter is None:
+            return
+        try:
+            report = dict(taskid=pbar.id_, first=False, last=True)
+            pbar.reporter.report(report)
+        except:
+            pass
 
 ##__________________________________________________________________||
