@@ -6,7 +6,7 @@ from .report import ProgressReportComplementer
 DEFAULT_INTERVAL = 0.1 # [second]
 
 ##__________________________________________________________________||
-class ProgressReporter(object):
+class ProgressReporter:
     """A progress reporter
 
     This class sends progress reports. The reports will be picked up
@@ -33,6 +33,10 @@ class ProgressReporter(object):
     of the task, will be always sent to the progress monitor
     regardless of whether it is given within the interval.
 
+    Parameters
+    ----------
+    queue : multiprocessing.Queue
+        The queue through which this class sends progress reports.
     """
     def __init__(self, queue):
         self.queue = queue
@@ -50,8 +54,10 @@ class ProgressReporter(object):
     def report(self, report):
         """send ``report`` to a progress monitor
 
-        Args:
-            report (ProgressReport): a progress report
+        Parameters
+        ----------
+        report : ProgressReport
+            a progress report
 
         """
 
@@ -62,7 +68,7 @@ class ProgressReporter(object):
 
         self.queue.put(report)
 
-        self.last_time[report['taskid']] = self._time()
+        self.last_time[report['taskid']] = time.time()
 
     def _need_to_report(self, report):
 
@@ -75,12 +81,9 @@ class ProgressReporter(object):
         if report['taskid'] not in self.last_time:
             return True
 
-        if self._time() - self.last_time[report['taskid']] > self.interval:
+        if time.time() - self.last_time[report['taskid']] > self.interval:
             return True
 
         return False
 
-    def _time(self):
-        return time.time()
-
 ##__________________________________________________________________||
